@@ -4,7 +4,7 @@ import threading
 import time
 from typing import Any, List, Optional
 
-from flask import Flask, Response, jsonify
+from flask import Flask, Response, jsonify, abort
 from flask import request as flaskrequest
 
 from .criteria import Criterion
@@ -20,6 +20,8 @@ logging.basicConfig(level=logging.INFO)
 @app.route("/<name>/<operation>/<step>", methods=["POST"])
 def _start_step(name: str, operation: str, step: str) -> Response:
     data = flaskrequest.json
+    if data is None:
+        abort(400, description="Expected JSON data")
     flow_information = data['flowInformation']
 
     logger.info("Executing " + str(flow_information['flowId']) + " step " + step)
@@ -65,6 +67,7 @@ class Slims(object):
         local_port (int, optional): The port on which this python script is running
             Needed for ports. SLims will contact the python script on this
             ports. Defaults to "5000"
+        request_params: Parameters to pass verbatim to requests when calling the REST API, e.g. verify='path/to/cert'
     """
 
     def __init__(self,
@@ -77,7 +80,8 @@ class Slims(object):
                  client_secret: str = None,
                  repo_location: str = None,
                  local_host: str = "localhost",
-                 local_port: int = 5000):
+                 local_port: int = 5000,
+                 **request_params: Any):
 
         slims_instances[name] = self
         self.local_host = local_host
@@ -85,7 +89,7 @@ class Slims(object):
         self.local_url = "http://" + self.local_host + \
             ":" + str(self.local_port) + "/"
         if username is not None and password is not None:
-            self.slims_api = _SlimsApi(url, username, password, repo_location)
+            self.slims_api = _SlimsApi(url, username, password, repo_location, **request_params)
         elif oauth:
             self.slims_api = _SlimsApi(url,
                                        "OAUTH",
@@ -95,7 +99,8 @@ class Slims(object):
                                        self.token_updater,
                                        self.local_url + name + "/token",
                                        client_id=client_id,
-                                       client_secret=client_secret)
+                                       client_secret=client_secret,
+                                       **request_params)
             self.token: Optional[dict[str, Any]] = None
         else:
             raise Exception(
